%ILT test - example from the Amazon (AMAZE study)
%last updated: 07/2009
%profiles taken at Noon (1 hour average)
%The source/sink distribution is calculated with the function ilt.m, which uses 4 more
%functions Tl.m (Lagrangian timescale: profile), sw.m (sigma(w): profile of standard deviation
%of vertical windspeed measured throughout the canopy), kn1.m and kn2.m (Kernel
%functions according to Raupach, FAM, 1989).
%For other real-world data sw.m needs to be changed according to each
%ecosystem. A generic shape has been proposed by Raupach, FAM, 1989. The
%present example uses measured sigma w profiles in the AMAZON during the
%AMAZE 2008 campaign.
h=40; %m canopy height
us=0.5; %m/s
tau=36000; %s

zm=[2 10.9 16.7 23.9 30.3 39]; % concentration vector
zc=[1:10]*zm(size(zm,2))/10; %interpolate concentrations to 17 levels
%IMPORTANT when defining source vector - lower and upper limit of source layer sh MUST lie
%between lower and upper limit of concentration vector zc: e.g. sh(1)>zc(1) and sh(size(sh,2))<zc(size(zc,2)
%In addition it is important that none of the elements of the source vector
%(sh) overlap with none of the elements in the concentration vector. 
dzc=zc(10)-zc(1);
steps=round(dzc/6);
sh=[zc(1):steps:zc(10)];

%make sure that sh levels stays within zc levels
if sh(size(sh,2))>=zc(10)
    sh(size(sh,2))=sh(size(sh,2))-0.1;
end

if sh(1)<=zc(1)
    sh(1)=sh(1)+0.1;
end

for i=2:size(sh,2)-1
    indx=find(sh(i)==zc);
    if ~isempty(indx)
        sh(i)=sh(i)-0.1;
    end
end

dsh(1)=sh(1)-0;
dsh(2:size(sh,2))=diff(sh);

%M69r=[7.2 8.152 8.779 8.538 8.598 7.483]';
%M137r=[0.6198 0.6453 0.7074 0.7039 0.804 0.6898]';

%Isoprene concentration at zm in (g/m3)

cm=[ 0.1405
    0.1590
    0.1713
    0.1666
    0.1677
    0.1460]*1e-4;

%Monoterpenes at zm in (g/m3) commented out
%cm=[0.0895
%    0.0932
%    0.1021
%    0.1016
%    0.1161
%    0.0996]*1e-4;

%interpolate concentration vector
c=interp1(zm,cm,zc);

%calculate source/sink distribution using the function ilt.m
source=ilt(c,zc,sh,tau,h,us)

%now plot results

figure; subplot(1,2,1); plot(source*1e9,sh); xlabel('Source-sink distribution [ng/m^2/s/m]'); ylabel('height [m]'); grid('on') %differential source distribution
subplot(1,2,2); plot(cumsum(source)*1e3*3.6e3*h/size(sh,2),sh); xlabel('Flux [mg/m^2/h]'); grid('on')